Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/qa
diff options
context:
space:
mode:
authorSanad Liaquat <sliaquat@gitlab.com>2019-01-18 17:12:00 +0300
committerSanad Liaquat <sliaquat@gitlab.com>2019-01-18 17:12:00 +0300
commit099613f41248f5c6d7ae5f6dfdb7a753e64c30cd (patch)
treede594a9afe94c443411d297a486420b9fc6c352c /qa
parentd74b3cc1867c92a84515397d08c70a2632417636 (diff)
Add qa element
Diffstat (limited to 'qa')
-rw-r--r--qa/qa/page/label/index.rb8
1 files changed, 6 insertions, 2 deletions
diff --git a/qa/qa/page/label/index.rb b/qa/qa/page/label/index.rb
index 4eb07a51a81..9344371a0b6 100644
--- a/qa/qa/page/label/index.rb
+++ b/qa/qa/page/label/index.rb
@@ -10,12 +10,16 @@ module QA
element :label_svg
end
+ view 'app/assets/javascripts/lazy_loader.js' do
+ element :js_lazy_loaded
+ end
+
def go_to_new_label
# The 'labels.svg' takes a fraction of a second to load after which the "New label" button shifts up a bit
# This can cause webdriver to miss the hit so we wait for the svg to load (implicitly with has_css?)
# before clicking the button.
within_element(:label_svg) do
- has_css?('.js-lazy-loaded')
+ has_element?(:js_lazy_loaded)
end
click_element :label_create_new
@@ -10,12 +10,16 @@ module QA
def go_to_new_label
# The 'labels.svg' takes a fraction of a second to load after which the "New label" button shifts up a bit
- # This can cause webdriver to miss the hit so we wait for the svg to load (implicitly with has_css?)
+ # This can cause webdriver to miss the hit so we wait for the svg to load (implicitly with has_element?)
# before clicking the button.
within_element(:label_svg) do